CREATE TABLE IF NOT EXISTS `tname`
STORED AS AVRO
AS
SELECT t0.*
FROM functional_alltypes t0